@@ -1,5 +1,5 @@
 package Astro::FITS::CFITSIO;
-$VERSION = '1.10';
+$VERSION = '1.11';
 
 use strict;
 use Carp;
@@ -39,6 +39,7 @@ my %__names = (
 	       ffbinr => 'fits_parse_binrange',
 	       ffdopn => 'fits_open_data',
 	       fftopn => 'fits_open_table',
+	       ffeopn => 'fits_open_extlist',
 	       ffiopn => 'fits_open_image',
 	       ffomem => 'fits_open_memfile',
 	       ffopen => 'fits_open_file',
@@ -140,6 +141,8 @@ my %__names = (
 	       ffgunt => 'fits_read_key_unit',
 	       ffgkyn => 'fits_read_keyn',
 	       ffgstr => 'fits_read_str',
+	       ffgksl => 'fits_read_key_strlen',
+	       ffgsky => 'fits_read_string_key',
 	       ffdstr => 'fits_delete_str',
 	       ffgky => 'fits_read_key',
 	       ffgkey => 'fits_read_keyword',
